//=========================================================
//  MusE
//  Linux Music Editor
//  $Id: audionodebutton.cpp,v 1.1.1.1 2003/10/29 10:05:23 wschweer Exp $
//
//  (C) Copyright 2000 Werner Schweer (ws@seh.de)
//=========================================================

#include "../audio.h"
#include "audionodebutton.h"

//---------------------------------------------------------
//   AudioNodeButton
//---------------------------------------------------------

AudioNodeButton::AudioNodeButton(QWidget* parent, AudioNode* s)
   : QToolButton(parent)
      {
      src = s;
      connect(this, SIGNAL(toggled(bool)), SLOT(toggled(bool)));
      }

//---------------------------------------------------------
//   volChanged
//---------------------------------------------------------

void AudioNodeButton::toggled(bool val)
      {
      emit audioNodeToggled(val, src);
      }

